@@ -3,7 +3,7 @@ from __future__ import annotations
 import keyword
 import logging
 from abc import ABC, abstractmethod
-from ast import literal_eval, Attribute, Name, GeneratorExp, Subscript, DictComp, ListComp, SetComp
+from ast import literal_eval, Attribute, Name, GeneratorExp, Subscript, DictComp, ListComp, SetComp, Constant, Str
 from dataclasses import dataclass, fields
 from itertools import count
 from typing import TYPE_CHECKING, Union, Optional, Iterator, Iterable, Type, TypeVar, Generic, List, Tuple
@@ -31,13 +31,16 @@ def convert_script(script: Script, add_methods: bool = False) -> str:
 
 class Converter(Generic[AC], ABC):
     converts: Type[AC] = None
+    newline_between_members: bool = False
     _ac_converter_map = {}
 
-    def __init_subclass__(cls, converts: Type[AC] = None, **kwargs):
+    def __init_subclass__(cls, converts: Type[AC] = None, newline_between_members: bool = None, **kwargs):
         super().__init_subclass__(**kwargs)
         if converts:
             cls.converts = converts
             cls._ac_converter_map[converts] = cls
+        if newline_between_members is not None:
+            cls.newline_between_members = newline_between_members
 
     def __init__(self, ast_obj: Union[AC, Script], parent: Optional[Converter] = None):
         self.ast_obj = ast_obj
@@ -90,7 +93,10 @@ class ConverterGroup(Generic[C]):
         yield from self.members
 
     def format_all(self, indent: int = 0) -> Iterator[str]:
-        for member in self.members:
+        newline_between_members = self.member_type.newline_between_members
+        for i, member in enumerate(self.members):
+            if i and newline_between_members:
+                yield ''
             yield from member.format_lines(indent)
 
 
@@ -284,7 +290,7 @@ class ParserConverter(CollectionConverter[AstArgumentParser], converts=AstArgume
     # endregion
 
 
-class GroupConverter(CollectionConverter[ArgGroup], converts=ArgGroup):
+class GroupConverter(CollectionConverter[ArgGroup], converts=ArgGroup, newline_between_members=True):
     ast_obj: ArgGroup
 
     def format_lines(self, indent: int = 4) -> Iterator[str]:
@@ -364,6 +370,10 @@ class ParamConverter(Converter[ParserArg], converts=ParserArg):
         return next(name for name in self._attr_name_candidates() if name not in RESERVED)
 
     def _attr_name_candidates(self) -> Iterator[str]:
+        dest = self.ast_obj.init_func_raw_kwargs.get('dest')
+        if dest is not None and isinstance(dest, (Constant, Str)):  # Str is for 3.7 compatibility
+            yield getattr(dest, dest._fields[0])  # .value for Constant, .s for Str
+
         long, short, plain = self._grouped_opt_strs
         if self.is_positional or self.is_pass_thru:
             yield from plain
@@ -439,6 +449,7 @@ class ParamConverter(Converter[ParserArg], converts=ParserArg):
         nargs = self.ast_obj.init_func_kwargs.get('nargs')
         if not nargs:
             return False
+        # TODO: Refactor to take advantage of new nargs=REMAINDER support
         return nargs in self.ast_obj.get_tracked_refs('argparse', 'REMAINDER', ())
 
     @cached_property
@@ -637,9 +648,16 @@ class FlagArgs(OptionArgs):
                 action = None
         else:
             if default == opposite:
-                default = None
+                const = None
+                if action == 'store_true':
+                    default = None
+            elif not default and action == 'store_false':
+                default = 'True'
+                const = None
+            else:
+                const = value if default else None
+
             action = None
-            const = value if default else None
 
         kwargs['type'] = kwargs['nargs'] = None
         if action:
