@@ -4,14 +4,19 @@ PassThru Parameters
 :author: Doug Skrypa
 """
 
-from typing import Collection, Any
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Collection, Any
 
 from ..context import ctx
 from ..exceptions import ParamUsageError, MissingArgument
 from ..nargs import Nargs
-from ..utils import _NotSet, Bool
+from ..utils import _NotSet
 from .base import Parameter, parameter_action
 
+if TYPE_CHECKING:
+    from ..typing import Bool
+
 __all__ = ['PassThru']
 
 
@@ -24,12 +29,10 @@ class PassThru(Parameter):
     :param kwargs: Additional keyword arguments to pass to :class:`.Parameter`.
     """
 
-    nargs = Nargs('*')
+    nargs = Nargs('REMAINDER')
     missing_hint: str = "missing pass thru args separated from others with '--'"
 
     def __init__(self, action: str = 'store_all', default: Any = _NotSet, required: Bool = False, **kwargs):
-        if 'choices' in kwargs:
-            raise TypeError(f"{self.__class__.__name__}.__init__() got an unexpected keyword argument 'choices'")
         if not required and default is _NotSet:
             default = None
         super().__init__(action=action, required=required, default=default, **kwargs)
